Description Usage Arguments Value Examples
Instead of modifying a closure's parent environment directly,
sometimes it may be desirable to do a one-time injection that
overrides what would normally be accessible through the closure.
call_with allows this by extending the usual do.call
to a third argument that is a list or environment temporarily
injected during the course of the call.
1 |
fn |
function. |
args |
list. The arguments to call the |
with |
list or environment. Additional locals to make available during the call. |
The result of calling fn with the injection provided
by the with parameter.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.